# Author:: Gerhard Spitzlsperger
# EMAIL and WWW:: ruby@gs68.de, www.gs68.de
# Copyright:: Copyright (c) 2003 Gerhard Spitzlsperger. All rights reserved.
# License:: LGPL see file LICENSE.
# Version 0.1

require 'fox'

include Fox

# A little dialog box to use in our tests
class GS_AreaDialog < FXDialogBox
  attr_reader :x_min, :x_max, :y_min, :y_max 
  
  def initialize(owner, a)
    # Invoke base class initialize function first
    super(owner, "Input drawing area range", DECOR_TITLE|DECOR_BORDER)

    # Bottom buttons
    buttons = FXHorizontalFrame.new(self,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,
      0, 0, 0, 0, 40, 40, 20, 20)

    # Separator
    FXHorizontalSeparator.new(self,
      LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE)
   
    # content
    contents = FXVerticalFrame.new(self,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)
 
    # x Contents
    contents_x = FXHorizontalFrame.new(contents,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)
 
    range_x = FXVerticalFrame.new(contents_x,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)
    
    # x_min
    xmin_f = FXHorizontalFrame.new(range_x,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)   
    FXLabel.new(xmin_f, "x Min.")
    @x_min = FXTextField.new(xmin_f, 10, nil, 0, TEXTFIELD_REAL|
      LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK)  
    @x_min.setText(a[0].to_s)
    
    # x max
    xmax_f = FXHorizontalFrame.new(range_x,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)    
    FXLabel.new(xmax_f, "x Max.")
    @x_max = FXTextField.new(xmax_f, 10, nil, 0, TEXTFIELD_REAL|
      LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK)  
    @x_max.setText(a[1].to_s)

    group_x = FXGroupBox.new(contents_x, "x axis",
      GROUPBOX_TITLE_CENTER|FRAME_RIDGE)
    FXRadioButton.new(group_x, "linear").connect(SEL_COMMAND) {
      p "x linear"
    }
    FXRadioButton.new(group_x, "logarithmic").connect(SEL_COMMAND) {
      p "x log"
    }  
    
    # Separator
    FXHorizontalSeparator.new(contents,
      LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE)
      
    # Y Contents
    contents_y = FXHorizontalFrame.new(contents,
      LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)
      
    range_y = FXVerticalFrame.new(contents_y,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)  
      
    # y min
    ymin_f = FXHorizontalFrame.new(range_y,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)    
    FXLabel.new(ymin_f, "y Min.")
    @y_min = FXTextField.new(ymin_f, 10, nil, 0, TEXTFIELD_REAL|
      LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK)  
    @y_min.setText(a[2].to_s)     
      
    # y max
    ymax_f = FXHorizontalFrame.new(range_y,
      LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH)        
    FXLabel.new(ymax_f, "y Max.")
    @y_max = FXTextField.new(ymax_f, 10, nil, 0, TEXTFIELD_REAL|
      LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK)  
    @y_max.setText(a[3].to_s)     
    
    
    group_y = FXGroupBox.new(contents_y, "y axis",
      GROUPBOX_TITLE_CENTER|FRAME_RIDGE)
    FXRadioButton.new(group_y, "linear").connect(SEL_COMMAND) {
      p "y linear"
    }
    FXRadioButton.new(group_y, "logarithmic").connect(SEL_COMMAND) {
      p "y log"
    }      
    
    # Cancel
    FXButton.new(buttons, "&Cancel", nil, self, ID_CANCEL,
      FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y)
          
    # Ok
    FXButton.new(buttons, "&Ok", nil, self, ID_ACCEPT,
      FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y)
  end
  
  def getResults
    return [@x_min.getText.to_f, @x_max.getText.to_f,
               @y_min.getText.to_f, @y_max.getText.to_f]
  end
end



