# Author:: Gerhard Spitzlsperger
# EMAIL and WWW:: ruby@gs68.de, www.gs68.de
# Copyright:: Copyright (c) 2003 Gerhard Spitzlsperger. All rights reserved.
# License:: LGPL see file LICENSE.
# Version 0.1

#require 'GS_AreaDialog'
#require 'GS_FramePlotCanvas'



require 'fox'
require 'fox/colors'

include Fox

require 'GS_Statistics'

class Array
  include GS_Statistics
end

class Data2d
  attr_reader   :header, :data, :norm_data

  def initialize
    @header = Array.new
    @data = Array.new
    @norm_data = Array.new
  end
  
  def readFile(filename)
    aFile = File.new(filename)
    
    # read the headerline
    line = aFile.gets.chomp
    temp = line.split(/,/)
    temp.each_index { |i|
      @header[i] = temp[i]
      @data[i] = Array.new
    }     

    # now read the rest
    while line = aFile.gets
      temp = line.chomp.split(/,/)
      temp.each_index { |i|
        @data[i].push(temp[i].to_f)
      }
    end   
  end
  
  # normalize the data to -1 .. +1
  def normalizeData
    for i in 0 .. 1
      @norm_data[i] = @data[i]
    end  
    
    for i in 2 .. @data.length - 1
      min = @data[i].min
      scale = 2.0 / (@data[i].max - min)
      
      @norm_data[i] = @data[i].map { |elem| -1.0 + scale * (elem - min) }
    end
  end
end  

class CanvasWindow < FXMainWindow  

  def initialize(app)
    # Call base class initializer first
    super(app, "Function Plotter", nil, nil, DECOR_ALL,
      0, 0, 1000, 600)

    # load some icons  
    killicon = getIcon("kill.gif")
      
    # Make menu bar
    menubar = FXMenubar.new(self, LAYOUT_FILL_X)
    
    # the file menu
    filemenu = FXMenuPane.new(self)  
    FXMenuTitle.new(menubar, "&File", nil, filemenu)
    readFileCmd = FXMenuCommand.new(filemenu, "&Read File")
    readFileCmd.connect(SEL_COMMAND, method(:onCmdReadFile))    
      
    FXMenuCommand.new(filemenu, "&Quit\tCtl-Q", nil,
      getApp(), FXApp::ID_QUIT)
     
    # the help menu
    helpmenu = FXMenuPane.new(self)
    FXMenuTitle.new(menubar, "&Help", nil, helpmenu, LAYOUT_RIGHT)
    FXMenuCommand.new(helpmenu, "&About FOX...").connect(SEL_COMMAND) {
      FXMessageBox.information(self, MBOX_OK, "About FOX",
        "FOX is a really, really cool C++ library...\n" +
        "and FXRuby is an even cooler GUI for Ruby!")
    }

    # Place a toolbar above the canvas
    toolbar = FXToolbar.new(self, (LAYOUT_SIDE_TOP|
      PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT|FRAME_RAISED|LAYOUT_FILL_X))
 
    FXButton.new(toolbar, "Exit\tExit", killicon, app, FXApp::ID_QUIT,
      ICON_ABOVE_TEXT|BUTTON_TOOLBAR|FRAME_RAISED)     
 
    # Horizontal divider line
    FXHorizontalSeparator.new(self, SEPARATOR_GROOVE|LAYOUT_FILL_X)

    @canvas = FXCanvas.new(self, nil, 0, (FRAME_SUNKEN|FRAME_THICK|
      LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_LEFT) )

      
    readFile  
      
    @canvas.connect(SEL_PAINT) do |canvas, sel, ev|
      dc = FXDCWindow.new(canvas, ev)
      draw(dc)
    end  
  end

  def draw(dc)
    dc = FXDCWindow.new(@canvas)
 
    dc.foreground = FXColor::White
    
    dc.fillRectangle(0, 0, @canvas.width, @canvas.height)      
    
    for i in 2..@dd.data.length - 1
      for j in 1..@dd.data[i].length - 1
        #p "#{i}, #{j}, #{@dd.data[i][j]}" 
        w = 2
        h = 10
	c = 128 + @dd.norm_data[i][j] * 127
        dc.foreground = FXRGB(c, c, c)
        dc.fillRectangle(5 + j*w, 5 + i*(h+2), w, h)
      end	
    end
  end
  
  def readFile
     @dd = Data2d.new
     @dd.readFile("data_special.csv")
     
     @dd.normalizeData
  end
  
  # read the file
  def onCmdReadFile(sender, sel, ptr)
     readFile
  end
  
  
  # function to construct a GIF icon
  def getIcon(filename)
    FXGIFIcon.new(getApp(), File.open(filename, "rb").read)
  end
  
  # Create and show the main window
  def create
    super                  # Create the windows
    show(PLACEMENT_SCREEN) # Make the main window appear
  end
end

def run
  # Construct the application object
  application = FXApp.new('Function Plotter', 'Fox Test')
  
  # Initialize it
  application.init(ARGV)
  
  # Construct the main window
  s = CanvasWindow.new(application)
  
  # Create the application
  application.create
  
  # Run the application
  application.run
end



# run the application
run